AndroidSettings class

Inheritance

Constructors

AndroidSettings({LocationAccuracy accuracy = LocationAccuracy.NAVIGATION, int interval = 5, double distanceFilter = 0, AndroidNotificationSettings androidNotificationSettings = const AndroidNotificationSettings(), int wakeLockTime = 60, LocationClient client = LocationClient.google})
accuracy The accuracy of location, Default is max accuracy NAVIGATION.
const

Properties

accuracy → LocationAccuracy
finalinherited
androidNotificationSettings → AndroidNotificationSettings
final
client → LocationClient
final
distanceFilter → double
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
interval → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wakeLockTime → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited